==> jc-1.4.0.tar.gz: javax/swing/LayoutFocusTraversalPolicy.h <==
// public class javax.swing.LayoutFocusTraversalPolicy

// class file dependencies
// @dep_class aa7caa0df83b76f6 java_awt_FocusTraversalPolicy
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 3cd22a3f5d3a5e41 javax_swing_InternalFrameFocusTraversalPolicy
// @dep_class 99546ec84029277 javax_swing_LayoutFocusTraversalPolicy
// @dep_class 5ff488f76845950a javax_swing_SortingFocusTraversalPolicy

// header file dependencies
// @dep_header javax_swing_SortingFocusTraversalPolicy

#include "javax/swing/SortingFocusTraversalPolicy.h"

#ifndef _JC_javax_swing_LayoutFocusTraversalPolicy_H_
#define _JC_javax_swing_LayoutFocusTraversalPolicy_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_javax_swing_LayoutFocusTraversalPolicy$sub_refs	_jc_javax_swing_LayoutFocusTraversalPolicy$sub_refs;
typedef struct _jc_javax_swing_LayoutFocusTraversalPolicy$sub_nonrefs	_jc_javax_swing_LayoutFocusTraversalPolicy$sub_nonrefs;
typedef struct _jc_javax_swing_LayoutFocusTraversalPolicy$refs	_jc_javax_swing_LayoutFocusTraversalPolicy$refs;
typedef struct _jc_javax_swing_LayoutFocusTraversalPolicy$nonrefs	_jc_javax_swing_LayoutFocusTraversalPolicy$nonrefs;
typedef struct _jc_javax_swing_LayoutFocusTraversalPolicy$object	_jc_javax_swing_LayoutFocusTraversalPolicy$object;

typedef const struct _jc_javax_swing_LayoutFocusTraversalPolicy$vmethods	_jc_javax_swing_LayoutFocusTraversalPolicy$vmethods;
typedef const struct _jc_javax_swing_LayoutFocusTraversalPolicy$vtable	_jc_javax_swing_LayoutFocusTraversalPolicy$vtable;
typedef const struct _jc_javax_swing_LayoutFocusTraversalPolicy$vtype	_jc_javax_swing_LayoutFocusTraversalPolicy$vtype;

// Constructors
extern void _jc_javax_swing_LayoutFocusTraversalPolicy$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_javax_swing_LayoutFocusTraversalPolicy$object *);

// Virtual methods structure
struct _jc_javax_swing_LayoutFocusTraversalPolicy$vmethods {
};

// Vtable
struct _jc_javax_swing_LayoutFocusTraversalPolicy$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_awt_FocusTraversalPolicy$vmethods	java_awt_FocusTraversalPolicy;
	_jc_javax_swing_InternalFrameFocusTraversalPolicy$vmethods	javax_swing_InternalFrameFocusTraversalPolicy;
	_jc_javax_swing_SortingFocusTraversalPolicy$vmethods	javax_swing_SortingFocusTraversalPolicy;
	_jc_javax_swing_LayoutFocusTraversalPolicy$vmethods	javax_swing_LayoutFocusTraversalPolicy;
};

// Vtype
struct _jc_javax_swing_LayoutFocusTraversalPolicy$vtype {
	_jc_type			type;
	_jc_javax_swing_LayoutFocusTraversalPolicy$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_LayoutFocusTraversalPolicy$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_swing_LayoutFocusTraversalPolicy$refs {
    _jc_javax_swing_LayoutFocusTraversalPolicy$sub_refs	javax_swing_LayoutFocusTraversalPolicy;
    _jc_javax_swing_SortingFocusTraversalPolicy$sub_refs	javax_swing_SortingFocusTraversalPolicy;
    _jc_javax_swing_InternalFrameFocusTraversalPolicy$sub_refs	javax_swing_InternalFrameFocusTraversalPolicy;
    _jc_java_awt_FocusTraversalPolicy$sub_refs	java_awt_FocusTraversalPolicy;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_LayoutFocusTraversalPolicy$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_LayoutFocusTraversalPolicy$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_awt_FocusTraversalPolicy$sub_nonrefs	java_awt_FocusTraversalPolicy;
    _jc_javax_swing_InternalFrameFocusTraversalPolicy$sub_nonrefs	javax_swing_InternalFrameFocusTraversalPolicy;
    _jc_javax_swing_SortingFocusTraversalPolicy$sub_nonrefs	javax_swing_SortingFocusTraversalPolicy;
    _jc_javax_swing_LayoutFocusTraversalPolicy$sub_nonrefs	javax_swing_LayoutFocusTraversalPolicy;
};

// Object instance structure
struct _jc_javax_swing_LayoutFocusTraversalPolicy$object {
	_jc_javax_swing_LayoutFocusTraversalPolicy$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_LayoutFocusTraversalPolicy$vtype	*vtype;
	_jc_javax_swing_LayoutFocusTraversalPolicy$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_LayoutFocusTraversalPolicy$vtype _jc_javax_swing_LayoutFocusTraversalPolicy$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_LayoutFocusTraversalPolicy, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_LayoutFocusTraversalPolicy$class_object;

#endif	/* _JC_javax_swing_LayoutFocusTraversalPolicy_H_ */

==> jc-1.4.5.tar.gz: javax/swing/LayoutFocusTraversalPolicy.h <==
// public class javax.swing.LayoutFocusTraversalPolicy

// class file dependencies
// @dep_class aa7caa0df83b76f6 java_awt_FocusTraversalPolicy
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 3cd22a3f5d3a5e41 javax_swing_InternalFrameFocusTraversalPolicy
// @dep_class 99546ec84029277 javax_swing_LayoutFocusTraversalPolicy
// @dep_class 5ff488f76845950a javax_swing_SortingFocusTraversalPolicy

// header file dependencies
// @dep_header javax_swing_SortingFocusTraversalPolicy

#include "javax/swing/SortingFocusTraversalPolicy.h"

#ifndef _JC_javax_swing_LayoutFocusTraversalPolicy_H_
#define _JC_javax_swing_LayoutFocusTraversalPolicy_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_javax_swing_LayoutFocusTraversalPolicy$sub_refs	_jc_javax_swing_LayoutFocusTraversalPolicy$sub_refs;
typedef struct _jc_javax_swing_LayoutFocusTraversalPolicy$sub_nonrefs	_jc_javax_swing_LayoutFocusTraversalPolicy$sub_nonrefs;
typedef struct _jc_javax_swing_LayoutFocusTraversalPolicy$refs	_jc_javax_swing_LayoutFocusTraversalPolicy$refs;
typedef struct _jc_javax_swing_LayoutFocusTraversalPolicy$nonrefs	_jc_javax_swing_LayoutFocusTraversalPolicy$nonrefs;
typedef struct _jc_javax_swing_LayoutFocusTraversalPolicy$object	_jc_javax_swing_LayoutFocusTraversalPolicy$object;

typedef const struct _jc_javax_swing_LayoutFocusTraversalPolicy$vmethods	_jc_javax_swing_LayoutFocusTraversalPolicy$vmethods;
typedef const struct _jc_javax_swing_LayoutFocusTraversalPolicy$vtable	_jc_javax_swing_LayoutFocusTraversalPolicy$vtable;
typedef const struct _jc_javax_swing_LayoutFocusTraversalPolicy$vtype	_jc_javax_swing_LayoutFocusTraversalPolicy$vtype;

// Constructors
extern void _jc_javax_swing_LayoutFocusTraversalPolicy$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_javax_swing_LayoutFocusTraversalPolicy$object *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_javax_swing_LayoutFocusTraversalPolicy$vmethods {
};

// Vtable
struct _jc_javax_swing_LayoutFocusTraversalPolicy$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_awt_FocusTraversalPolicy$vmethods	java_awt_FocusTraversalPolicy;
	_jc_javax_swing_InternalFrameFocusTraversalPolicy$vmethods	javax_swing_InternalFrameFocusTraversalPolicy;
	_jc_javax_swing_SortingFocusTraversalPolicy$vmethods	javax_swing_SortingFocusTraversalPolicy;
	_jc_javax_swing_LayoutFocusTraversalPolicy$vmethods	javax_swing_LayoutFocusTraversalPolicy;
};

// Vtype
struct _jc_javax_swing_LayoutFocusTraversalPolicy$vtype {
	_jc_type			type;
	_jc_javax_swing_LayoutFocusTraversalPolicy$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_LayoutFocusTraversalPolicy$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_swing_LayoutFocusTraversalPolicy$refs {
    _jc_javax_swing_LayoutFocusTraversalPolicy$sub_refs	javax_swing_LayoutFocusTraversalPolicy;
    _jc_javax_swing_SortingFocusTraversalPolicy$sub_refs	javax_swing_SortingFocusTraversalPolicy;
    _jc_javax_swing_InternalFrameFocusTraversalPolicy$sub_refs	javax_swing_InternalFrameFocusTraversalPolicy;
    _jc_java_awt_FocusTraversalPolicy$sub_refs	java_awt_FocusTraversalPolicy;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_LayoutFocusTraversalPolicy$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_LayoutFocusTraversalPolicy$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_awt_FocusTraversalPolicy$sub_nonrefs	java_awt_FocusTraversalPolicy;
    _jc_javax_swing_InternalFrameFocusTraversalPolicy$sub_nonrefs	javax_swing_InternalFrameFocusTraversalPolicy;
    _jc_javax_swing_SortingFocusTraversalPolicy$sub_nonrefs	javax_swing_SortingFocusTraversalPolicy;
    _jc_javax_swing_LayoutFocusTraversalPolicy$sub_nonrefs	javax_swing_LayoutFocusTraversalPolicy;
};

// Object instance structure
struct _jc_javax_swing_LayoutFocusTraversalPolicy$object {
	_jc_javax_swing_LayoutFocusTraversalPolicy$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_LayoutFocusTraversalPolicy$vtype	*vtype;
	_jc_javax_swing_LayoutFocusTraversalPolicy$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_LayoutFocusTraversalPolicy$vtype _jc_javax_swing_LayoutFocusTraversalPolicy$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_LayoutFocusTraversalPolicy, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_LayoutFocusTraversalPolicy$class_object;

#endif	/* _JC_javax_swing_LayoutFocusTraversalPolicy_H_ */
